"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createServerFolders = void 0;
const www_1 = require("./www");
const fs_1 = __importDefault(require("fs"));
const projectDir = {
    defaultFiles: { package: "package.json", gitignore: ".gitignore" },
    bin: { folder: "bin", fileName: "www" },
    src: {
        folder: "src",
        configFolder: {
            folder: "config",
            index: "index.js",
            constants: "constants.js",
            httpCodes: "httpCodes.js",
            messages: "messages.js",
            mongooseConnection: "mongoose.connection.js",
        },
        helperFolder: {
            folder: "helpers",
            index: "index.js",
            response: "response.js",
            routeHandler: "routeHandler.js",
            errorHandler: "errorHandler.js",
            errorResponse: {
                folder: "errorResponse",
                index: "index.js",
                badRequest: "badRequest.js",
                errorResponse: "errorResponse.js",
                notFound: "notFound.js",
                precondition: "precondition.js",
                unauthorized: "unauthorized.js",
                unhandled: "unhandled.js",
            },
        },
        middlewares: {
            folder: "middlewares",
            index: "index.js",
            authorization: "authorization.js",
            uploadFile: "uploadFile.js",
            validation: "validation.js",
        },
        database: {
            folder: "database",
            models: {
                folder: "models",
                index: "index.js",
                modelName: "name.model.js",
            },
            seeders: {
                folder: "seeders",
                index: "index.js",
            },
        },
        public: {
            folder: "public",
            index: "index.html",
            client: {
                folder: "client",
                client: "client.js",
            },
            images: {
                folder: "images",
            },
        },
        routes: {
            folder: "routes",
            index: "index.js",
        },
        modules: {
            folder: "modules",
            users: {
                folder: "users",
                index: "index.js",
                usersRoutes: "users.routes.js",
                usersController: "users.controller.js",
                usersService: "users.service.js",
                usersValidation: "users.validation.js",
            },
        },
        utils: {
            folder: "utils",
            index: "index.js",
            emailTemplates: {
                folder: "emailTemplates",
            },
        },
    },
};
const createServerFolders = ({ appName }) => __awaiter(void 0, void 0, void 0, function* () {
    const { metadata } = yield (0, www_1.wwwFileCreator)({ appName });
    if (!fs_1.default.existsSync(appName)) {
        console.log("NoT Exist");
        fs_1.default.mkdirSync(appName);
        const fileContent = {
            name: "hello",
        };
        let data = `console.log('Hello, Ts');`;
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.defaultFiles.package}`, JSON.stringify(fileContent));
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.defaultFiles.gitignore}`, "#fileContent");
        // bin
        fs_1.default.mkdirSync(`./${appName}/${projectDir.bin.folder}`);
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.bin.folder}/${projectDir.bin.fileName}`, metadata);
        // src
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}`);
        // config
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.configFolder.folder}`);
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.configFolder.folder}/${projectDir.src.configFolder.index}`, metadata);
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.configFolder.folder}/${projectDir.src.configFolder.constants}`, metadata);
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.configFolder.folder}/${projectDir.src.configFolder.httpCodes}`, metadata);
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.configFolder.folder}/${projectDir.src.configFolder.messages}`, metadata);
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.configFolder.folder}/${projectDir.src.configFolder.mongooseConnection}`, metadata);
        // database
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.database.folder}`);
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.database.folder}/${projectDir.src.database.models.folder}`);
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.database.folder}/${projectDir.src.database.models.folder}/${projectDir.src.database.models.index}`, metadata);
        // files
        fs_1.default.writeFileSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.database.folder}/${projectDir.src.database.models.folder}/${projectDir.src.database.models.modelName}`, metadata);
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.database.folder}/${projectDir.src.database.seeders.folder}`);
        // helpers
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.helperFolder.folder}`);
        // middlewares
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.middlewares.folder}`);
        // utils
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.utils.folder}`);
        // routes
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.routes.folder}`);
        // modules
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.modules.folder}`);
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.modules.folder}/${projectDir.src.modules.users.folder}`);
        // public
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.public.folder}`);
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.public.folder}/${projectDir.src.public.client.folder}`);
        fs_1.default.mkdirSync(`./${appName}/${projectDir.src.folder}/${projectDir.src.public.folder}/${projectDir.src.public.images.folder}`);
        console.log(`Project '${appName}' created.`);
    }
    else {
        console.log("Exist");
    }
    return metadata;
});
exports.createServerFolders = createServerFolders;
